.. _sponsors:

********
Sponsors
********

The Mopidy project would like to thank the following sponsors for supporting
the project.


Rackspace
=========

`Rackspace <https://www.rackspace.com/>`_ lets Mopidy use their hosting
services for free. We use their services for the following sites:

- Hosting of the APT package repository at https://apt.mopidy.com.

- OAuth bridges at https://auth.mopidy.com.


Fastly
======

`Fastly <https://www.fastly.com/>`_ lets Mopidy use their CDN for free. We
accelerate requests to most Mopidy services, including:

- https://apt.mopidy.com/dists/, which is used to distribute Debian packages.


Discourse
=========

`Discourse <https://www.discourse.org/>`_ sponsors Mopidy with free hosting of
our discussion forum at https://discourse.mopidy.com.
